#!/bin/bash

# Output last 30 days of observations

# create and execute query that will output last 30 days of data
# into aq30d.csv file

cat <<EOF | sqlite3 aqmonitor.db
.headers on
.mode csv
.output aq30d.csv
-- Get last 30 days
select
  min(date) as date,
  strftime('%Y-%m-%d %H', date) as dayHr, 
  avg(pm25Env) as pm25EnvAvg, min(pm25Env) as pm25EnvMin, max(pm25Env) as pm25EnvMax,
  avg(pm100Env-pm25Env) as pm100EnvAvg, min(pm100Env-pm25Env) as pm100EnvMin, max(pm100Env-pm25Env) as pm100EnvMax
from observations
where 
  date > datetime('now','localtime','-30 days')
group by dayhr
EOF

# This query determines the max Y value that will be plotted so we can 
# handle labels cleanly in the plot

maxPM=$(cat <<EOF | sqlite3 aqmonitor.db
select
  max(max(pm25Env), max(pm100Env-pm25Env)) as maxPM
from observations
where date > datetime('now','localtime','-30 days')
EOF
)

cat <<EOF | gnuplot 
    maxPM=${maxPM}
    set datafile separator ','							#CSV field separator
    set title "Particulate Matter for Last 30 Days" font ",20"			#header
    # display Max obs above and right of the graph
    set label 99 sprintf("Maximum Observation: %d", maxPM) at graph 1, graph 1 right offset 0, char 1
    
    set xdata time 								#tells gnuplot the x axis is time data
    set timefmt "%Y-%m-%d %H:%M" 						#specify our time string format
    set format x "%b %d" 							#otherwise it will show only MM:SS
    set xtics rotate
    
    set ylabel "PM (grams / meter^{3})" 					#label for the Y axis    
    set ytics nomirror								#no Y ticks at top

    # setup legend box
    set style line 100 lt 1 lc rgb "dark-grey" lw 0.5                           # linestyle for the grid
    set grid ls 100 front                                                       # enable grid with specific linestyle
    
    # create colored background of bars 
    set object 50 rect from graph 0, graph 0  to graph 1, first 12        fc rgb "green"  lw 0 
    set object 51 rect from graph 0, first 12 to graph 1, first 35.4      fc rgb "yellow" lw 0
    set object 52 rect from graph 0, first 35.4  to graph 1, first 55.4   fc rgb "orange" lw 0
    set object 53 rect from graph 0, first 55.4  to graph 1, first 150.4  fc rgb "red"    lw 0
    set object 54 rect from graph 0, first 150.4 to graph 1, first 250.4  fc rgb "purple" lw 0
    set object 55 rect from graph 0, first 250.4 to graph 1, graph 1      fc rgb "brown"  lw 0

    # Labels for the colored bars a defined based on which bars are actually displayed
    if (maxPM <= 12) {
      set yrange[0:12]
      set label 50 "Good"                           at graph 0.5, first 6    center tc rgb "black"
    }
    if (maxPM > 12 && maxPM <= 35) {
      set yrange[0:35]
      set label 50 "Good"                           at graph 0.5, first 6    center tc rgb "black"
      set label 51 "Moderate"                       at graph 0.5, first 24   center tc rgb "black"
    }
    if (maxPM > 35 && maxPM <= 55) {
      set yrange[0:55]
      set label 50 "Good"                           at graph 0.5, first 6    center tc rgb "black"
      set label 51 "Moderate"                       at graph 0.5, first 24   center tc rgb "black"
      set label 52 "Unhealthy for Sensitive Groups" at graph 0.5, first 45   center tc rgb "black"
    }
    if (maxPM > 55 && maxPM <= 150) {
      set yrange[0:150]
      set label 50 "Good"                           at graph 0.5, first 6    center tc rgb "black"
      set label 51 "Moderate"                       at graph 0.5, first 24   center tc rgb "black"
      set label 52 "Unhealthy for Sensitive Groups" at graph 0.5, first 45   center tc rgb "black"
      set label 53 "Unhealthy"			    at graph 0.5, first 100  center tc rgb "black"
    }
    if (maxPM > 150 && maxPM <= 250) {
      set yrange[0:250]
      set label 50 "Good"                           at graph 0.5, first 6    center tc rgb "black"
      set label 51 "Moderate"                       at graph 0.5, first 24   center tc rgb "black"
      set label 52 "Unhealthy for Sensitive Groups" at graph 0.5, first 45   center tc rgb "black"
      set label 53 "Unhealthy"			    at graph 0.5, first 100  center tc rgb "black"
      set label 54 "Very Unhealthy"                 at graph 0.5, first 200  center tc rgb "black"
    }
    if (maxPM > 250) {
      set yrange[0:500<*]
      set label 53 "Unhealthy"			    at graph 0.5, first 100  center tc rgb "black"
      set label 54 "Very Unhealthy"                 at graph 0.5, first 200  center tc rgb "black"
      if (maxPM <= 500) {
        set label 55 "Hazardous"                    at graph 0.5, first (500-250)/2+250    center tc rgb "black"
        }
      else {
        set label 55 "Hazardous"	            at graph 0.5, first (maxPM-250)/2+250  center tc rgb "black" #Y position calculated to be centered
      }
    }
    
    set style line 101               lw 1 lt rgb "black"                        #line color for PM2.5
    set style line 102 dashtype "-." lw 1 lt rgb "blue"				#line color for PM10
    
    # output graphic definitions
    set terminal pngcairo size 800,600 
    set output "aq30d.png"

    plot 'aq30d.csv' using 1:3 with lines ls 101 title 'Avg PM2.5',\
        ''         using 1:5 with lines ls 102 title 'Max PM2.5'
EOF


